@@ -42,7 +42,7 @@ namespace Bindings {
 
 class Config : public BindingObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     TQ_PROPERTY( bool forceGlobal READ forceGlobal WRITE setForceGlobal )
     TQ_PROPERTY( bool dollarExpansion READ isDollarExpansion WRITE setDollarExpansion )
     TQ_PROPERTY( bool readOnly READ isReadOnly WRITE setReadOnly )
