@@ -94,12 +94,12 @@ void JSConsoleWidget::createView()
     go = new TQPushButton( i18n("&Run"), cmdBox, "run_button" );
     go->setFixedSize( go->sizeHint() );
 
-    connect( cmd, TQT_SIGNAL(returnPressed(const TQString&)), go, TQT_SLOT( animateClick() ) );
-    connect( go, TQT_SIGNAL( clicked() ), TQT_SLOT( invoke() ) );
+    connect( cmd, TQ_SIGNAL(returnPressed(const TQString&)), go, TQ_SLOT( animateClick() ) );
+    connect( go, TQ_SIGNAL( clicked() ), TQ_SLOT( invoke() ) );
 
     // Setup completion
     TDECompletion *comp = cmd->completionObject();
-    connect( cmd, TQT_SIGNAL(returnPressed(const TQString&)), comp, TQT_SLOT(addItem(const TQString&)) );
+    connect( cmd, TQ_SIGNAL(returnPressed(const TQString&)), comp, TQ_SLOT(addItem(const TQString&)) );
 
     // Layout
     TQVBoxLayout *vert = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
@@ -192,11 +192,11 @@ bool JSConsoleWidget::run( const TQString &cmd )
     proc = new KShellProcess("/bin/sh");
     *proc << cmd;
 
-    connect( proc, TQT_SIGNAL( processExited(TDEProcess *) ), TQT_SLOT( childExited() ) );
-    connect( proc, TQT_SIGNAL( receivedStdout(TDEProcess *, char *, int) ),
-	     this, TQT_SLOT( receivedStdOutput(TDEProcess *, char *, int) ) );
-    connect( proc, TQT_SIGNAL( receivedStderr(TDEProcess *, char *, int) ),
-	     this, TQT_SLOT( receivedStdError(TDEProcess *, char *, int) ) );
+    connect( proc, TQ_SIGNAL( processExited(TDEProcess *) ), TQ_SLOT( childExited() ) );
+    connect( proc, TQ_SIGNAL( receivedStdout(TDEProcess *, char *, int) ),
+	     this, TQ_SLOT( receivedStdOutput(TDEProcess *, char *, int) ) );
+    connect( proc, TQ_SIGNAL( receivedStderr(TDEProcess *, char *, int) ),
+	     this, TQ_SLOT( receivedStdError(TDEProcess *, char *, int) ) );
 
     return proc->start( TDEProcess::NotifyOnExit,
 			TDEProcess::Communication( TDEProcess::Stdout|TDEProcess::Stderr ));
