@@ -52,7 +52,7 @@
 #define TQM_EXPORT_CANVAS
 #define TQM_TEMPLATE_EXTERN_CANVAS
 #else
-#define TQM_EXPORT_CANVAS Q_EXPORT
+#define TQM_EXPORT_CANVAS TQ_EXPORT
 #define TQM_TEMPLATE_EXTERN_CANVAS Q_TEMPLATE_EXTERN
 #endif
 
@@ -133,16 +133,6 @@ public:
     virtual void setActive(bool yes);
     bool isActive() const
 	{ return (bool)act; }
-#ifndef TQT_NO_COMPAT
-    bool visible() const
-	{ return (bool)vis; }
-    bool selected() const
-	{ return (bool)sel; }
-    bool enabled() const
-	{ return (bool)ena; }
-    bool active() const
-	{ return (bool)act; }
-#endif
 
     enum RttiValues {
 	Rtti_Item = 0,
@@ -208,7 +198,7 @@ class TQCanvasData;
 
 class TQM_EXPORT_CANVAS TQCanvas : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     TQCanvas( TQObject* parent = 0, const char* name = 0 );
     TQCanvas(int w, int h);
@@ -354,7 +344,7 @@ class TQCanvasViewData;
 
 class TQM_EXPORT_CANVAS TQCanvasView : public TQScrollView
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
 
     TQCanvasView(TQWidget* parent=0, const char* name=0, WFlags f=0);
