@@ -6,7 +6,7 @@ include KDE
 class SenderWidget < PushButton
 	def initialize(parent, name)
 		super
-		connect(self, SIGNAL('clicked()'), self, SLOT('doit()'))
+		connect(self, TQ_SIGNAL('clicked()'), self, TQ_SLOT('doit()'))
 	end
 	
 	slots 'doit()'
