@@ -19,8 +19,8 @@ class LCDRange < TQt::Widget
         @label = TQt::Label.new( ' ', self, 'label'  )
         @label.setAlignment( TQt::AlignCenter )
             
-        connect(@slider, SIGNAL('valueChanged(int)'), @lcd, SLOT('display(int)'))
-        connect(@slider, SIGNAL('valueChanged(int)'), SIGNAL('valueChanged(int)'))
+        connect(@slider, TQ_SIGNAL('valueChanged(int)'), @lcd, TQ_SLOT('display(int)'))
+        connect(@slider, TQ_SIGNAL('valueChanged(int)'), TQ_SIGNAL('valueChanged(int)'))
         
         setFocusProxy(@slider)
         
